summaryrefslogtreecommitdiff
path: root/gcc/testsuite/gcc.dg
diff options
context:
space:
mode:
authorjanis <janis@138bc75d-0d04-0410-961f-82ee72b054a4>2007-01-29 20:27:41 +0000
committerjanis <janis@138bc75d-0d04-0410-961f-82ee72b054a4>2007-01-29 20:27:41 +0000
commit2675096e48d1ef9f42f2c53228aa8056a0bfa353 (patch)
treed407fcd3b280b3bac4ca0e3402c1ca361e758548 /gcc/testsuite/gcc.dg
parent339496f1c781c9119990172651d6b8fbe6258e68 (diff)
downloadgcc-2675096e48d1ef9f42f2c53228aa8056a0bfa353.tar.gz
gcc/
* Makefile.in (USER_H): Remove decfloat.h. * ginclude/decfloat.h: Delete, moving contents to ... * ginclude/float.h: Add support for decimal floating point, guarded by __STDC_WANT_DEC_FP__. gcc/testsuite/ * gcc.dg/dfp/dec-eval-method.c: Replace decfloat.h with float.h. * gcc.dg/dfp/decfloat-constants.c: Ditto. * gcc.dg/dfp/convert-dfp.c: Ditto. * gcc.dg/dfp/convert-int-saturate.c: Ditto. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@121308 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/testsuite/gcc.dg')
-rw-r--r--gcc/testsuite/gcc.dg/dfp/convert-dfp.c3
-rw-r--r--gcc/testsuite/gcc.dg/dfp/convert-int-saturate.c3
-rw-r--r--gcc/testsuite/gcc.dg/dfp/dec-eval-method.c4
-rw-r--r--gcc/testsuite/gcc.dg/dfp/decfloat-constants.c9
4 files changed, 11 insertions, 8 deletions
diff --git a/gcc/testsuite/gcc.dg/dfp/convert-dfp.c b/gcc/testsuite/gcc.dg/dfp/convert-dfp.c
index bafe0894b63..5afdcf0b7a2 100644
--- a/gcc/testsuite/gcc.dg/dfp/convert-dfp.c
+++ b/gcc/testsuite/gcc.dg/dfp/convert-dfp.c
@@ -6,7 +6,8 @@
Test various conversions involving decimal floating types. */
-#include <decfloat.h>
+#define __STDC_WANT_DEC_FP__ 1
+#include <float.h>
extern void abort (void);
diff --git a/gcc/testsuite/gcc.dg/dfp/convert-int-saturate.c b/gcc/testsuite/gcc.dg/dfp/convert-int-saturate.c
index 9aeb1d70c6e..aeaa4655ac4 100644
--- a/gcc/testsuite/gcc.dg/dfp/convert-int-saturate.c
+++ b/gcc/testsuite/gcc.dg/dfp/convert-int-saturate.c
@@ -4,7 +4,8 @@
C99 6.3.1.4(1a) New.
Test integer saturation. */
-#include <decfloat.h>
+#define __STDC_WANT_DEC_FP__ 1
+#include <float.h>
#include <limits.h>
extern void abort (void);
diff --git a/gcc/testsuite/gcc.dg/dfp/decfloat-constants.c b/gcc/testsuite/gcc.dg/dfp/decfloat-constants.c
index 62461e6cfaf..4980c6532a9 100644
--- a/gcc/testsuite/gcc.dg/dfp/decfloat-constants.c
+++ b/gcc/testsuite/gcc.dg/dfp/decfloat-constants.c
@@ -1,13 +1,14 @@
/* { dg-options "-std=gnu99" } */
-/* N1150 4: Characteristics of decimal floating types <decfloat.h>.
+/* N1150 4: Characteristics of decimal floating types <float.h>.
C99 5.2.4.2.2a[3]: New.
Verify constants about range of decimal float and three components of
- decimal float defined in decfloat.h. */
+ decimal float defined in float.h. */
-/* Make sure we are exporting the right values to decfloat.h. */
-#include <decfloat.h>
+/* Make sure we are exporting the right values to float.h. */
+#define __STDC_WANT_DEC_FP__ 1
+#include <float.h>
extern void abort (void);
diff --git a/gcc/testsuite/gcc.dg/dfp/dec-eval-method.c b/gcc/testsuite/gcc.dg/dfp/dec-eval-method.c
index e1ccbb794c0..070a4033e02 100644
--- a/gcc/testsuite/gcc.dg/dfp/dec-eval-method.c
+++ b/gcc/testsuite/gcc.dg/dfp/dec-eval-method.c
@@ -1,11 +1,11 @@
/* { dg-do compile } */
/* { dg-options "-std=gnu99" } */
/* N1107 4: Characteristics of decimal floating types <decfloat.h>.
C99 5.2.4.2.2a[2] (New).
Verify that __DEC_EVAL_METHOD__ is defined; it will be used to define
- DEC_EVAL_METHOD in <decfloat.h>. */
+ DEC_EVAL_METHOD in <float.h>. */
int i;
#ifndef __DEC_EVAL_METHOD__
@@ -1,11 +1,11 @@
/* { dg-do compile } */
/* { dg-options "-std=gnu99" } */
-/* N1107 4: Characteristics of decimal floating types <decfloat.h>.
+/* N1107 4: Characteristics of decimal floating types <float.h>.
C99 5.2.4.2.2a[2] (New).
Verify that __DEC_EVAL_METHOD__ is defined; it will be used to define